#
# spec file for package bpftool
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Use default LLVM on openSUSE unless it is not yet supported
%if 0%{?suse_version} >= 1600 || 0%{?is_opensuse}
 %if 0%{?product_libs_llvm_ver} > 17
 %define llvm_major_version 17
 %else
 %define llvm_major_version %{nil}
 %endif
%else
 # Hard-code latest LLVM for SLES, the default version is too old
 %if 0%{?sle_version} == 150600
  %define llvm_major_version 17
 %else
 %if 0%{?sle_version} == 150500
  %define llvm_major_version 15
 %else
 %if 0%{?sle_version} == 150400
  %define llvm_major_version 11
 %endif
 %endif
 %endif
%endif

Name:           bpftool
%define version %(rpm -q --qf '%%{VERSION}' kernel-source)
Version:        %{version}
Release:        150600.19.6.1
Summary:        Tool for inspection and manipulation of BPF programs and maps
License:        GPL-2.0-only
Group:          Development/Tools/Other
Url:            http://www.kernel.org/
# Can be dropped once the follow made it's way into kernel-source
Patch0:         bpftool-Fix-undefined-behavior-in-qsort-NULL-0.patch
# Needed for compiling included BPF program (i.e. skeletons)
BuildRequires:  clang%{llvm_major_version}
BuildRequires:  docutils
BuildRequires:  dwarves
BuildRequires:  kernel-source
BuildRequires:  libelf-devel
# llvm-strip is needed for the included BPF program (i.e. skeletons)
BuildRequires:  llvm%{llvm_major_version}

%description
bpftool allows for inspection and simple modification of BPF objects (programs
and maps) on the system.

%prep
(cd /usr/src/linux ; tar -cf - COPYING CREDITS README tools include scripts Kbuild Makefile arch/*/{include,lib,Makefile} kernel/bpf lib) | tar -xf -
cp /usr/src/linux/LICENSES/preferred/GPL-2.0 .
sed -i -e 's/CFLAGS += -O2/CFLAGS = $(RPM_OPT_FLAGS)/' Makefile

%autopatch -p1

%build
cd tools/bpf/bpftool
%make_build V=1 feature-reallocarray=1 all doc

%install
cd tools/bpf/bpftool
make install doc-install DESTDIR=%{buildroot} prefix=%{_prefix} mandir=%{_mandir}

%files
%license GPL-2.0
%{_sbindir}/bpftool
%{_datadir}/bash-completion/completions/bpftool
%{_mandir}/man?/*.gz

%changelog
* Thu Nov  7 2024 shung-hsi.yu@suse.com
- Fix undefined behavior in qsort(NULL, 0, ...) (bsc#1232258
  CVE-2024-49987)
  * add bpftool-Fix-undefined-behavior-in-qsort-NULL-0.patch
* Wed May 22 2024 shung-hsi.yu@suse.com
- Enable showing info for processes holding BPF map/prog/link/btf FDs
  (jsc#PED-8375)
* Mon Jan 22 2024 shung-hsi.yu@suse.com
- Update bpftool to align with v6.5-based kernel
  * show map IDs along with struct_ops links
  * show map IDs instead of raw value for map_of_maps types
  * show target_{obj,btf}_id in tracing link info
* Fri Oct 20 2023 shung-hsi.yu@suse.com
- Update bpftool align with v6.4-based kernel
  + Support for KIND_RESTRICT in gen min_core_btf command
  + Support BPF_MAP_TYPE_USER_RINGBUF map type
  + Support new cgroup local storage
  + Support printing opcodes and source file references in CFG
  + Probe for memcg-based accounting and bump rlimit only if needed
  + Allow toggling autoattach for bpf prog load|loadall
  + Remove support of --legacy option for bpftool
  + Remove BPF_OBJ_NAME_LEN restriction when looking up bpf program by name
* Fri Sep  1 2023 shung-hsi.yu@suse.com
- Update bpftool align with v5.19-based kernel
  + Implement BTFGen (i.e gen min_core_btf command)
  + Support for new btf kind BTF_KIND_DECL_TAG and BTF_KIND_TYPE_TAG
  + Support multiple .rodata/.data internal maps in skeleton
  + Probes for bounded loops, instruction set extensions, and offload-enabled
  + Generate Light skeleton for the kernel
  + Enable libbpf's strict mode by default
  + Show program & link type names
  + Support showing program names declared in BTF
  + Add BPF_TRACE_KPROBE_MULTI to attach type names table
  + Check unprivileged_bpf_disabled against value of 2
  + Use sysfs vmlinux when dumping BTF by ID
- Drop libbpf-Fix-BTF-to-C-converter-s-padding-logic.patch as the fix is now
  included
* Wed May  3 2023 shung-hsi.yu@suse.com
- Add dwarves as build dependency as pahole is called during build
- Fix BTF-to-C converter's padding logic (jsc#PED-3924)
  New patch: libbpf-Fix-BTF-to-C-converter-s-padding-logic.patch
* Wed Jan  8 2020 lnussel@suse.de
- use optflags for building
- build and install man pages
* Thu May  9 2019 mrostecki@opensuse.org
- Initial release
